! Update litter and lignine content after litter fall.
! Calculate litter decomposition.
!
! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/stomate_litter.f90,v 1.3 2002/09/24 21:12:17 ssipsl Exp $
!
MODULE stomate_litter

  ! modules used:

  USE ioipsl
  USE stomate_constants

  IMPLICIT NONE

  ! private & public routines

  PRIVATE
  PUBLIC littercalc,littercalc_clear, deadleaf

    ! first call
    LOGICAL, SAVE                                                     :: firstcall = .TRUE.

CONTAINS

  SUBROUTINE littercalc_clear
    firstcall =.TRUE.
  END SUBROUTINE littercalc_clear


  SUBROUTINE littercalc (npts, dt, space_nat, &
                         turnover, bm_to_litter, &
                         tsurf, tsoil, soilhum, litterhum, &
                         litterpart, litter, dead_leaves, lignin_struc, &
                         deadleaf_cover, resp_hetero_litter, &
                         soilcarbon_input, control_temp, control_moist)

    !
    ! 0 declarations
    !

    ! 0.1 input

    ! Domain size
    INTEGER, INTENT(in)                                               :: npts
    ! time step in days
    REAL(stnd), INTENT(in)                                            :: dt
    ! total natural space (fraction of total space)
    REAL(stnd), DIMENSION(npts), INTENT(in)                           :: space_nat
    ! Turnover rates (gC/(m**2 of nat/agri ground)/day)
    REAL(stnd), DIMENSION(npts,npft,nparts), INTENT(in)               :: turnover
    ! conversion of biomass to litter (gC/(m**2 of average nat. or agric. ground)) / day
    REAL(stnd), DIMENSION(npts,npft,nparts), INTENT(in)               :: bm_to_litter
    ! temperature (K) at the surface
    REAL(stnd), DIMENSION(npts), INTENT(in)                           :: tsurf
    ! soil temperature (K)
    REAL(stnd), DIMENSION(npts,nbdl), INTENT(in)                      :: tsoil
    ! daily soil humidity
    REAL(stnd), DIMENSION(npts,nbdl), INTENT(in)                      :: soilhum
    ! daily litter humidity
    REAL(stnd), DIMENSION(npts), INTENT(in)                           :: litterhum

    ! 0.2 modified fields

    ! fraction of litter above the ground belonging to different PFTs
    REAL(stnd), DIMENSION(npts,npft,nlitt), INTENT(inout)             :: litterpart
    ! metabolic and structural litter, natural and agricultural,
    !   above and below ground (gC/m**2 of natural or agricultural ground)
    REAL(stnd), DIMENSION(npts,nlitt,nvegtypes,nlevs), INTENT(inout)  :: litter
    ! dead leaves on ground, per PFT, metabolic and structural,
    !   in gC/(m**2 of nat/agri ground)
    REAL(stnd), DIMENSION(npts,npft,nlitt), INTENT(inout)             :: dead_leaves
    ! ratio Lignine/Carbon in structural litter, above and below ground,
    !   natural and agricultural (gC/m**2)
    REAL(stnd), DIMENSION(npts,nvegtypes,nlevs), INTENT(inout)        :: lignin_struc

    ! 0.3 output

    ! fraction of soil covered by dead leaves
    REAL(stnd), DIMENSION(npts), INTENT(out)                          :: deadleaf_cover
    ! litter heterotrophic respiration (first in gC/day/m**2 of natural/agricultural ground,
    !   but output in gC/day/m**2 of total ground)
    REAL(stnd), DIMENSION(npts,nvegtypes), INTENT(out)                :: resp_hetero_litter
    ! quantity of carbon going into carbon pools from litter decomposition
    !   (gC/(m**2 of nat/agri ground)/day)
    REAL(stnd), DIMENSION(npts,ncarb,nvegtypes), INTENT(out)          :: soilcarbon_input
    ! temperature control of heterotrophic respiration, above and below
    REAL(stnd), DIMENSION(npts,nlevs), INTENT(out)                    :: control_temp
    ! moisture control of heterotrophic respiration
    REAL(stnd), DIMENSION(npts,nlevs), INTENT(out)                    :: control_moist

    ! 0.4 local

    ! C/N ratio
    REAL(stnd), SAVE, DIMENSION(nparts)                               :: CN
    ! what fraction of leaves, wood, etc. goes into metabolic and structural litterpools
    REAL(stnd), SAVE, DIMENSION(nparts,nlitt)                         :: litterfrac
    ! Lignine/C ratio of the different plant parts
    REAL(stnd), SAVE, DIMENSION(nparts)                               :: LC
    ! soil levels (m)
    REAL(stnd), SAVE, DIMENSION(0:nbdl)                               :: z_soil
    ! scaling depth for soil activity (m)
    REAL(stnd), PARAMETER                                             :: z_decomp = 0.2
    ! integration constant for vertical profiles
    REAL(stnd), DIMENSION(npts)                                       :: rpc
    ! residence time in litter pools (days)
    REAL(stnd), SAVE, DIMENSION(nlitt)                                :: litter_tau
    ! decomposition flux fraction that goes into soil (litter -> carbon, above and below)
    !   rest goes into atmosphere
    REAL(stnd), SAVE, DIMENSION(nlitt,ncarb,nlevs)                    :: frac_soil
    ! temperature used for decompostition in soil (K)
    REAL(stnd), DIMENSION(npts)                                       :: tsoil_decomp
    ! humidity used for decompostition in soil
    REAL(stnd), DIMENSION(npts)                                       :: soilhum_decomp
    ! fraction of structural or metabolic litter decomposed
    REAL(stnd), DIMENSION(npts)                                       :: fd
    ! quantity of structural or metabolic litter decomposed (gC/m**2)
    REAL(stnd), DIMENSION(npts)                                       :: qd
    ! old structural litter, natural and agricultural, above and below (gC/m**2)
    REAL(stnd), DIMENSION(npts,nvegtypes,nlevs)                       :: old_struc
    ! increase of litter, per PFT, metabolic and structural,
    !   above and below ground (gC/m**2 of natural or agricultural ground)
    REAL(stnd), DIMENSION(npts,npft,nlitt,nlevs)                      :: litter_inc_PFT
    ! increase of metabolic and structural litter, natural and agricultural,
    !   above and below ground (gC/m**2 of natural or agricultural ground)
    REAL(stnd), DIMENSION(npts,nlitt,nvegtypes,nlevs)                 :: litter_inc
    ! lignin increase in structural litter, natural and agricultural,
    !   above and below ground (gC/m**2 of natural or agricultural ground)
    REAL(stnd), DIMENSION(npts,nvegtypes,nlevs)                       :: lignin_struc_inc
    ! metabolic and structural litter above the ground per PFT ( for natural PFTs)
    REAL(stnd), DIMENSION(npts,npft,nlitt)                            :: litter_pft
    ! intermediate array for looking for minimum
    REAL(stnd), DIMENSION(npts)                                       :: zdiff_min
    ! for messages
    CHARACTER*10, DIMENSION(nlitt)                                    :: litter_str
    CHARACTER*22, DIMENSION(nparts)                                   :: part_str
    CHARACTER*7, DIMENSION(ncarb)                                     :: carbon_str
    CHARACTER*5, DIMENSION(nlevs)                                     :: level_str
    ! Indices
    INTEGER(long)                                                     :: i,j,k,l,m

    ! =========================================================================

    IF (bavard.GE.3) WRITE(numout,*) 'Entering littercalc'

    !
    ! 1 Initialisations
    !

    IF ( firstcall ) THEN

      !
      ! 1.1 get soil "constants"
      !

      ! 1.1.1 C/N ratios
  
      CN(ileaf) = 40.0
      CN(isapabove) = 40.0
      CN(isapbelow) = 40.0
      CN(iheartabove) = 40.0
      CN(iheartbelow) = 40.0
      CN(iroot) = 40.0
      CN(ifruit) = 40.0
      CN(icarbres) = 40.0
  
      ! 1.1.2 Lignine/C ratios
  
      LC(ileaf) = 0.22
      LC(isapabove) = 0.35
      LC(isapbelow) = 0.35
      LC(iheartabove) = 0.35
      LC(iheartbelow) = 0.35
      LC(iroot) = 0.22
      LC(ifruit) = 0.22
      LC(icarbres) = 0.22
  
      ! 1.1.3 litter fractions:
      !   what fraction of leaves, wood, etc. goes into metabolic and structural litterpools
  
      DO k = 1, nparts
  
        litterfrac(k,imetabolic) = 0.85 - 0.018 * LC(k) * CN(k)
        litterfrac(k,istructural) = 1. - litterfrac(k,imetabolic)

      ENDDO

      ! 1.1.4 residence times in litter pools (days)

      litter_tau(imetabolic) = .066 * one_year      !!!!???? .5 years
      litter_tau(istructural) = .245 * one_year     !!!!???? 3 years

      ! 1.1.5 decomposition flux fraction that goes into soil
      !       (litter -> carbon, above and below)
      !       1-frac_soil goes into atmosphere

      frac_soil(:,:,:) = undef

      ! structural litter: lignin fraction goes into slow pool + respiration,
      !                    rest into active pool + respiration
      frac_soil(istructural,iactive,iabove) = .55
      frac_soil(istructural,iactive,ibelow) = .45
      frac_soil(istructural,islow,iabove) = .7
      frac_soil(istructural,islow,ibelow) = .7

      ! metabolic litter: all goes into active pool + respiration.
      !   Nothing into slow or passive pool.
      frac_soil(imetabolic,iactive,iabove) = .45
      frac_soil(imetabolic,iactive,ibelow) = .45
 
      !
      ! 1.2 soil levels
      !

      z_soil(0) = 0.
      z_soil(1:nbdl) = diaglev(1:nbdl)

      !
      ! 1.3 messages
      !

      litter_str(imetabolic) = 'metabolic'
      litter_str(istructural) = 'structural'

      carbon_str(iactive) = 'active'
      carbon_str(islow) = 'slow'
      carbon_str(ipassive) = 'passive'

      level_str(iabove) = 'above'
      level_str(ibelow) = 'below'

      part_str(ileaf) = 'leaves'
      part_str(isapabove) = 'sap above ground'
      part_str(isapbelow) = 'sap below ground'
      part_str(iheartabove) = 'heartwood above ground'
      part_str(iheartbelow) = 'heartwood below ground'
      part_str(iroot) = 'roots'
      part_str(ifruit) = 'fruits'
      part_str(icarbres) = 'carbohydrate reserve'

      WRITE(numout,*) 'litter:'

      WRITE(numout,*) '   > C/N ratios: '
      DO k = 1, nparts
        WRITE(numout,*) '       ', part_str(k), ': ',CN(k)
      ENDDO

      WRITE(numout,*) '   > Lignine/C ratios: '
      DO k = 1, nparts
        WRITE(numout,*) '       ', part_str(k), ': ',LC(k)
      ENDDO

      WRITE(numout,*) '   > fraction of compartment that goes into litter: '
      DO k = 1, nparts
        DO m = 1, nlitt
          WRITE(numout,*) '       ', part_str(k), '-> ',litter_str(m), ':',litterfrac(k,m)
        ENDDO
      ENDDO

      WRITE(numout,*) '   > scaling depth for decomposition (m): ',z_decomp

      WRITE(numout,*) '   > minimal carbon residence time in litter pools (d):'
      DO m = 1, nlitt
        WRITE(numout,*) '       ',litter_str(m),':',litter_tau(m)
      ENDDO

      WRITE(numout,*) '   > litter decomposition flux fraction that really goes '
      WRITE(numout,*) '     into carbon pools (rest into the atmosphere):'
      DO m = 1, nlitt
        DO l = 1, nlevs
          DO k = 1, ncarb
            WRITE(numout,*) '       ',litter_str(m),' ',level_str(l),' -> ',&
                            carbon_str(k),':', frac_soil(m,k,l)
          ENDDO
        ENDDO
      ENDDO

      firstcall = .FALSE.

    ENDIF

    !
    ! 1.3 litter above the ground per PFT.
    !

    DO j = 1, npft

      IF ( natural(j) ) THEN
        m = inat
      ELSE
        m = iagri
      ENDIF

      DO k = 1, nlitt
        litter_pft(:,j,k) = litterpart(:,j,k) * litter(:,k,m,iabove)
      ENDDO

    ENDDO

    !
    ! 1.4 set output to zero
    !

    deadleaf_cover(:) = 0.0
    resp_hetero_litter(:,:) = 0.0
    soilcarbon_input(:,:,:) = 0.0

    !
    ! 2 Add biomass to different litterpools (per m**2 of nat/agri ground)
    !

    !
    ! 2.1 first, save old structural litter (needed for lignin fractions).
    !     nat/agri, above/below
    !

    DO l = 1, nlevs
      DO m = 1, nvegtypes

        old_struc(:,m,l) = litter(:,istructural,m,l)

      ENDDO
    ENDDO

    !
    ! 2.2 update litter, dead leaves, and lignin content in structural litter
    !

    litter_inc(:,:,:,:) = 0.0
    lignin_struc_inc(:,:,:) = 0.0

    DO j = 1, npft

      ! 2.2.1 natural or agricultural litter

      IF ( natural(j) ) THEN
        m = inat
      ELSE
        m = iagri
      ENDIF

      DO k = 1, nlitt    ! metabolic and structural

        ! 2.2.2 calculate litter increase (per m**2 of average agricultural or 
        !       natural ground).
        !       Only a given fracion of fruit turnover is directly coverted into litter.
        !       Litter increase for each PFT, structural and metabolic, above/below

        litter_inc_PFT(:,j,k,iabove) = &
          litterfrac(ileaf,k) * bm_to_litter(:,j,ileaf) + &
          litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove) + &
          litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove) + &
          litterfrac(ifruit,k) * bm_to_litter(:,j,ifruit) + &
          litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres) + &
          litterfrac(ileaf,k) * turnover(:,j,ileaf) + &
          litterfrac(isapabove,k) * turnover(:,j,isapabove) + &
          litterfrac(iheartabove,k) * turnover(:,j,iheartabove) + &
          litterfrac(ifruit,k) * turnover(:,j,ifruit) + &
          litterfrac(icarbres,k) * turnover(:,j,icarbres)

        litter_inc_PFT(:,j,k,ibelow) = &
          litterfrac(isapbelow,k) * bm_to_litter(:,j,isapbelow) + &
          litterfrac(iheartbelow,k) * bm_to_litter(:,j,iheartbelow) + &
          litterfrac(iroot,k) * bm_to_litter(:,j,iroot) + &
          litterfrac(isapbelow,k) * turnover(:,j,isapbelow) + &
          litterfrac(iheartbelow,k) * turnover(:,j,iheartbelow) + &
          litterfrac(iroot,k) * turnover(:,j,iroot)

        ! litter increase, met/struct, nat/agri, above/below

        litter_inc(:,k,m,iabove) = litter_inc(:,k,m,iabove) + litter_inc_PFT(:,j,k,iabove)
        litter_inc(:,k,m,ibelow) = litter_inc(:,k,m,ibelow) + litter_inc_PFT(:,j,k,ibelow)

        ! 2.2.3 dead leaves, for soil cover.

        dead_leaves(:,j,k) = &
          dead_leaves(:,j,k) + &
          litterfrac(ileaf,k) * ( bm_to_litter(:,j,ileaf) + turnover(:,j,ileaf) )

        ! 2.2.4 lignin increase in structural litter

        IF ( k .EQ. istructural ) THEN

          lignin_struc_inc(:,m,iabove) = &
            lignin_struc_inc(:,m,iabove) + &
            LC(ileaf) * bm_to_litter(:,j,ileaf) + &
            LC(isapabove) * bm_to_litter(:,j,isapabove) + &
            LC(iheartabove) * bm_to_litter(:,j,iheartabove) + &
            LC(ifruit) * bm_to_litter(:,j,ifruit) + &
            LC(icarbres) * bm_to_litter(:,j,icarbres) + &
            LC(ileaf) * turnover(:,j,ileaf) + &
            LC(isapabove) * turnover(:,j,isapabove) + &
            LC(iheartabove) * turnover(:,j,iheartabove) + &
            LC(ifruit) * turnover(:,j,ifruit) + &
            LC(icarbres) * turnover(:,j,icarbres)

          lignin_struc_inc(:,m,ibelow) = &
            lignin_struc_inc(:,m,ibelow) + &
            LC(isapbelow) * bm_to_litter(:,j,isapbelow) + &
            LC(iheartbelow) * bm_to_litter(:,j,iheartbelow) + &
            LC(iroot) * bm_to_litter(:,j,iroot) + &
            LC(isapbelow)*turnover(:,j,isapbelow) + &
            LC(iheartbelow)*turnover(:,j,iheartbelow) + &
            LC(iroot)*turnover(:,j,iroot)

        ENDIF

      ENDDO
    ENDDO

    ! 3.2.5 add new litter (struct/met, nat/agri, above/below)

    litter(:,:,:,:) = litter(:,:,:,:) + litter_inc(:,:,:,:)

    ! 3.2.6 for security: can't add more lignin than structural litter
    !       (nat/agri, above/below)

    DO l = 1, nlevs
      DO m = 1, nvegtypes

        lignin_struc_inc(:,m,l) = &
          MIN( lignin_struc_inc(:,m,l), litter_inc(:,istructural,m,l) )

      ENDDO
    ENDDO

    ! 3.2.7 new lignin content: add old lignin and lignin increase, divide by 
    !       total structural litter (nat/agri, above/below)

    WHERE ( litter(:,istructural,:,:) .GT. 0.0 )

      lignin_struc(:,:,:) = &
               ( lignin_struc(:,:,:)*old_struc(:,:,:) + lignin_struc_inc(:,:,:) ) / &
               litter(:,istructural,:,:)

    ENDWHERE

    !
    ! 3.3 new litter fraction per PFT (for structural and metabolic litter, above
    !       the ground). Fractions are calculated separately for the natural and
    !       for the agricultural ground.
    !

    DO j = 1, npft

      IF ( natural(j) ) THEN
        m = inat
      ELSE
        m = iagri
      ENDIF

      WHERE ( litter(:,:,m,iabove) .GT. 0.0 )

        litterpart(:,j,:) = &
          ( litter_pft(:,j,:) + litter_inc_PFT(:,j,:,iabove) ) / litter(:,:,m,iabove)

      ELSEWHERE

        litterpart(:,j,:) = 0.0

      ENDWHERE

    ENDDO

    !
    ! 4 Temperature control on decay: Factor between 0 and 1
    !

    !
    ! 4.1 above: surface temperature
    !

    control_temp(:,iabove) = control_temp_func (npts, tsurf)

    !
    ! 4.2 below: convolution of temperature and decomposer profiles
    !            (exponential decomposer profile supposed)
    !

    ! 4.2.1 rpc is an integration constant such that the integral of the root profile is 1.
    rpc(:) = 1. / ( 1. - EXP( -z_soil(nbdl) / z_decomp ) )

    ! 4.2.2 integrate over the nbdl levels

    tsoil_decomp(:) = 0.0

    DO l = 1, nbdl

      tsoil_decomp(:) = &
        tsoil_decomp(:) + tsoil(:,l) * rpc(:) * &
                        ( EXP( -z_soil(l-1)/z_decomp ) - EXP( -z_soil(l)/z_decomp ) )

    ENDDO

    control_temp(:,ibelow) = control_temp_func (npts, tsoil_decomp)

    !
    ! 5 Moisture control. Factor between 0 and 1
    !

    !
    ! 5.1 above the ground: litter humidity
    !

    control_moist(:,iabove) = control_moist_func (npts, litterhum)

    !
    ! 5.2 below: convolution of humidity and decomposer profiles
    !            (exponential decomposer profile supposed)
    !

    ! 4.2.1 rpc is an integration constant such that the integral of the root profile is 1.
    rpc(:) = 1. / ( 1. - EXP( -z_soil(nbdl) / z_decomp ) )

    ! 4.2.2 integrate over the nbdl levels

    soilhum_decomp(:) = 0.0

    DO l = 1, nbdl

      soilhum_decomp(:) = &
        soilhum_decomp(:) + soilhum(:,l) * rpc(:) * &
                            ( EXP( -z_soil(l-1)/z_decomp ) - EXP( -z_soil(l)/z_decomp ) )

    ENDDO

    control_moist(:,ibelow) = control_moist_func (npts, soilhum_decomp)

    !
    ! 6 fluxes from litter to carbon pools and respiration
    !

    DO l = 1, nlevs
      DO m = 1, nvegtypes

        !
        ! 6.1 structural litter: goes into active and slow carbon pools + respiration
        !

        ! 6.1.1 total quantity of structural litter which is decomposed

        fd(:) = dt/litter_tau(istructural) * &
                control_temp(:,l) * control_moist(:,l) * exp( -3. * lignin_struc(:,m,l) )

        qd(:) = litter(:,istructural,m,l) * fd(:)

        litter(:,istructural,m,l) = litter(:,istructural,m,l) - qd(:)

        ! 6.1.2 decompose same fraction of structural part of dead leaves. Not exact
        !       as lignine content is not the same as that of the total structural litter.

        DO j = 1, npft
          dead_leaves(:,j,istructural) = dead_leaves(:,j,istructural) * ( 1. - fd(:) )
        ENDDO

        ! 6.1.3 non-lignin fraction of structural litter goes into
        !       active carbon pool + respiration

        soilcarbon_input(:,iactive,m) = soilcarbon_input(:,iactive,m) + &
            frac_soil(istructural,iactive,l) * qd(:) * ( 1. - lignin_struc(:,m,l) ) / dt

        resp_hetero_litter(:,m) = resp_hetero_litter(:,m) + &
            ( 1. - frac_soil(istructural,iactive,l) ) * qd(:) * &
            ( 1. - lignin_struc(:,m,l) ) / dt

        ! 6.1.4 lignin fraction of structural litter goes into
        !       slow carbon pool + respiration

        soilcarbon_input(:,islow,m) = soilcarbon_input(:,islow,m) + &
            frac_soil(istructural,islow,l) * qd(:) * lignin_struc(:,m,l) / dt

        resp_hetero_litter(:,m) = resp_hetero_litter(:,m) + &
            ( 1. - frac_soil(istructural,islow,l) ) * qd(:) * lignin_struc(:,m,l) / dt

        !
        ! 6.2 metabolic litter goes into active carbon pool + respiration
        !

        ! 6.2.1 total quantity of metabolic litter that is decomposed

        fd(:) = dt/litter_tau(imetabolic) * control_temp(:,l) * control_moist(:,l)

        qd(:) = litter(:,imetabolic,m,l) * fd(:)

        litter(:,imetabolic,m,l) = litter(:,imetabolic,m,l) - qd(:)

        ! 6.2.2 decompose same fraction of metabolic part of dead leaves.

        DO j = 1, npft
          dead_leaves(:,j,imetabolic) = dead_leaves(:,j,imetabolic) * ( 1. - fd(:) )
        ENDDO

        ! 6.2.3 put decomposed litter into carbon pool + respiration

        soilcarbon_input(:,iactive,m) = soilcarbon_input(:,iactive,m) + &
                              frac_soil(imetabolic,iactive,l) * qd(:) / dt

        resp_hetero_litter(:,m) = resp_hetero_litter(:,m) + &
                           ( 1. - frac_soil(imetabolic,iactive,l) ) * qd(:) / dt

      ENDDO
    ENDDO

    !
    ! 7 transform respiration from gC/day/(m**2 of nat/agri ground) to
    !   gC/day/(m**2 of total ground), as it goes into the atmosphere.
    !

    resp_hetero_litter(:,iagri) = resp_hetero_litter(:,iagri) * ( 1. - space_nat(:) )
    resp_hetero_litter(:,inat) = resp_hetero_litter(:,inat) * ( space_nat(:) )

    !
    ! 8 calculate fraction of total soil covered by dead leaves
    !

    CALL deadleaf (npts, space_nat, dead_leaves, deadleaf_cover)

    IF (bavard.GE.4) WRITE(numout,*) 'Leaving littercalc'

  END SUBROUTINE littercalc

  SUBROUTINE deadleaf (npts, space_nat, dead_leaves, deadleaf_cover)

    !
    ! 0 declarations
    !

    ! 0.1 input

    ! Domain size
    INTEGER, INTENT(in)                                               :: npts
    ! total natural space (fraction of total space)
    REAL(stnd), DIMENSION(npts), INTENT(in)                           :: space_nat
    ! dead leaves on ground, per PFT, metabolic and structural,
    !   in gC/(m**2 of nat/agri ground)
    REAL(stnd), DIMENSION(npts,npft,nlitt), INTENT(in)                :: dead_leaves

    ! 0.2. output
    ! fraction of soil covered by dead leaves
    REAL(stnd), DIMENSION(npts), INTENT(out)                          :: deadleaf_cover

    ! 0.3. local

    ! LAI of dead leaves
    REAL(stnd), DIMENSION(npts)                                       :: dead_lai
    ! Index
    INTEGER(long)                                                     :: j

    !
    ! 1 LAI of dead leaves
    !

    dead_lai(:) = 0.0

    DO j = 1, npft

      IF ( natural(j) ) THEN
        dead_lai(:) = dead_lai(:) + space_nat(:) * &
           ( dead_leaves(:,j,imetabolic) + dead_leaves(:,j,istructural) ) * sla(j)
      ELSE
        dead_lai(:) = dead_lai(:) + ( 1. - space_nat(:) ) * &
           ( dead_leaves(:,j,imetabolic) + dead_leaves(:,j,istructural) ) * sla(j)
      ENDIF

    ENDDO

    !
    ! 2 fraction of soil covered by dead leaves
    !

    deadleaf_cover(:) = 1. - exp( - 0.5 * dead_lai(:) )

    IF (bavard.GE.4) WRITE(numout,*) 'Leaving deadleaf'

  END SUBROUTINE deadleaf

  FUNCTION control_moist_func (npts, moist_in) RESULT (moistfunc_result)

    !
    ! 0 declarations
    !

    ! 0.1 input

    ! Domain size
    INTEGER, INTENT(in)                                               :: npts
    ! relative humidity
    REAL(stnd), DIMENSION(npts), INTENT(in)                           :: moist_in

    ! 0.2 result

    ! moisture control factor
    REAL(stnd), DIMENSION(npts)                                       :: moistfunc_result

    moistfunc_result(:) = -1.1 * moist_in(:) * moist_in(:) + 2.4 * moist_in(:) - 0.29
    moistfunc_result(:) = MAX( 0.25_stnd, MIN( 1._stnd, moistfunc_result(:) ) )

  END FUNCTION control_moist_func

  FUNCTION control_temp_func (npts, temp_in) RESULT (tempfunc_result)

    !
    ! 0 declarations
    !

    ! 0.1 input

    ! Domain size
    INTEGER, INTENT(in)                                               :: npts
    ! temperature (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                           :: temp_in

    ! 0.2 result

    ! temperature control factor
    REAL(stnd), DIMENSION(npts)                                       :: tempfunc_result

    tempfunc_result(:) = exp( 0.69 * ( temp_in(:) - (ZeroCelsius+30.) ) / 10. )
    tempfunc_result(:) = MIN( 1._stnd, tempfunc_result(:) )

  END FUNCTION control_temp_func

END MODULE stomate_litter
